@@ -7,7 +7,6 @@ from typing import Dict, Iterable, List, Optional, Tuple
 import pandas as pd
 
 try:
-    import grpc
     from ethereumetl.jobs.export_blocks_job import ExportBlocksJob
     from ethereumetl.jobs.export_receipts_job import ExportReceiptsJob
     from ethereumetl.jobs.export_traces_job import (
@@ -27,6 +26,7 @@ try:
     from .tron.grpc.api.tron_api_pb2 import EmptyMessage, NumberMessage
     from .tron.grpc.api.tron_api_pb2_grpc import WalletStub
     from .tron.txTypeTransformer import TxTypeTransformer
+    from graphsenselib.utils.grpc import get_channel
 except ImportError:
     _has_ingest_dependencies = False
 else:
@@ -42,7 +42,6 @@ from ..utils import (
     first_or_default,
     hex_to_bytes,
     parse_timestamp,
-    remove_prefix,
     strip_0x,
 )
 from ..utils.account import get_id_group
@@ -68,6 +67,23 @@ WEB3_QUERY_BATCH_SIZE = 50
 WEB3_QUERY_WORKERS = 40
 
 
+def enrich_txs_with_vrs(
+    txs: Iterable[Dict], receipts: Iterable[Dict]
+) -> Iterable[Dict]:
+    # enrich tx strips v, r, s from txs so we add them back
+    tx_hash_to_vrs = {tx["hash"]: (tx.get("v"), tx.get("r"), tx.get("s")) for tx in txs}
+
+    enriched_txs = enrich_transactions(txs, receipts)
+
+    for etx in enriched_txs:
+        v, r, s = tx_hash_to_vrs[etx["hash"]]
+        etx["v"] = v
+        etx["r"] = r
+        etx["s"] = s
+
+    return enriched_txs
+
+
 class InMemoryItemExporter:
     """In-memory item exporter for EthStreamerAdapter export jobs."""
 
@@ -286,8 +302,8 @@ class TronStreamerAdapter(AccountStreamerAdapter):
     def export_hash_to_type_mappings(
         self, transactions: Iterable, blocks: Iterable, block_id_name="block_id"
     ) -> Dict:
-        grpc_endpoint = remove_prefix(self.grpc_endpoint, "grpc://")
-        channel = grpc.insecure_channel(grpc_endpoint)
+        grpc_endpoint = self.grpc_endpoint
+        channel = get_channel(grpc_endpoint)
         wallet_stub = WalletStub(channel)
 
         def get_type(tx):
@@ -312,8 +328,8 @@ class TronStreamerAdapter(AccountStreamerAdapter):
     def export_hash_to_type_mappings_parallel(
         self, blocks: Iterable, block_id_name="block_id"
     ) -> Dict:
-        grpc_endpoint = remove_prefix(self.grpc_endpoint, "grpc://")
-        channel = grpc.insecure_channel(grpc_endpoint)
+        grpc_endpoint = self.grpc_endpoint
+        channel = get_channel(grpc_endpoint)
         wallet_stub = WalletStub(channel)
 
         def get_type(tx):
@@ -346,9 +362,9 @@ class TronStreamerAdapter(AccountStreamerAdapter):
     def get_trc10_token_infos(self) -> Iterable[Dict]:
         """Get all trc10 tokens from a grpc endpoint"""
 
-        grpc_endpoint = remove_prefix(self.grpc_endpoint, "grpc://")
+        grpc_endpoint = self.grpc_endpoint
 
-        channel = grpc.insecure_channel(grpc_endpoint)
+        channel = get_channel(grpc_endpoint)
         wallet_stub = WalletStub(channel)
         trc10_tokens = wallet_stub.GetAssetIssueList(EmptyMessage())
 
@@ -535,6 +551,7 @@ def prepare_transactions_inplace_eth(
         "receipt_contract_address",
         "receipt_root",
     ]
+
     for item in items:
         # remove column
         item.pop("type")
@@ -836,7 +853,7 @@ def ingest(
                 traces, fees = adapter.export_traces(
                     block_id, current_end_block, True, True
                 )
-                enriched_txs = enrich_transactions(txs, receipts)
+                enriched_txs = enrich_txs_with_vrs(txs, receipts)
 
             # reformat and edit data
             prepare_logs_inplace(logs, BLOCK_BUCKET_SIZE)
@@ -1013,7 +1030,7 @@ class EthETLStrategy(AbstractETLStrategy):
         return enriched_txs
 
     def enrich_transactions(self, txs, receipts):
-        return enrich_transactions(txs, receipts)
+        return enrich_txs_with_vrs(txs, receipts)
 
     def transform_traces(self, traces, block_bucket_size: int):
         prepare_traces_inplace_eth(traces, block_bucket_size)
