@@ -44,6 +44,20 @@ class Taxonomies(IntEnum):
 
 class InheritedFrom(IntEnum):
     CLUSTER = 1
+    PUBKEY = 2
+    PUBKEY_AND_CLUSTER = 3
+
+    @staticmethod
+    def from_string(s: str) -> "InheritedFrom":
+        s_lower = s.lower()
+        if s_lower == "cluster":
+            return InheritedFrom.CLUSTER
+        elif s_lower == "pubkey":
+            return InheritedFrom.PUBKEY
+        elif s_lower == "pubkey_and_cluster":
+            return InheritedFrom.PUBKEY_AND_CLUSTER
+        else:
+            raise ValueError(f"Unknown InheritedFrom string: {s}")
 
 
 _ALL_TAXONOMIES = {
@@ -214,6 +228,10 @@ class TagPublic(BaseModel):
             ).keys()
         )
 
+    @property
+    def tagpack_is_public(self) -> bool:
+        return self.group == "public"
+
     @classmethod
     def fromDB(cls, t: Tag, tp: TagPack, inherited_from=None) -> "TagPublic":
         c = t.concepts
@@ -639,7 +657,7 @@ class TagstoreDbAsync:
 
     @_inject_session
     async def get_tag_count_by_subjectid(
-        self, subject_id: str, network: str, groups: List[str], session=None
+        self, subject_id: str, network: Optional[str], groups: List[str], session=None
     ) -> int:
         results = await session.exec(
             _get_tag_count_by_subjectid_stmt(subject_id, network, groups)
@@ -925,18 +943,32 @@ class TagstoreDbAsync:
 
     @_inject_session
     async def search_labels(
-        self, label: str, limit: int, groups: List[str], session=None
+        self,
+        label: str,
+        limit: int,
+        groups: List[str],
+        query_actors: bool = True,
+        query_labels: bool = True,
+        session=None,
     ) -> LabelSearchResultPublic:
         return LabelSearchResultPublic(
-            actor_labels=await self.search_actor_labels(
-                label.strip(), limit, session=session
-            ),
-            tag_labels=[
-                HumanReadableId(id=x, label=x)
-                for x in (
-                    await self.search_tag_labels(label, limit, groups, session=session)
-                )
-            ],
+            actor_labels=(
+                await self.search_actor_labels(label.strip(), limit, session=session)
+            )
+            if query_actors
+            else [],
+            tag_labels=(
+                [
+                    HumanReadableId(id=x, label=x)
+                    for x in (
+                        await self.search_tag_labels(
+                            label, limit, groups, session=session
+                        )
+                    )
+                ]
+            )
+            if query_labels
+            else [],
         )
 
     @_inject_session
